Miscellaneous
=============


Sparse Pauli
-------------

.. automodule:: panqec.bsparse
    :members:
    :special-members: __init__

Dense Pauli
------------

.. automodule:: panqec.bpauli
    :members:
    :special-members: __init__

Utilities
----------

.. automodule:: panqec.utils
    :members:
    :special-members: __init__

IO
---

.. automodule:: panqec.io
    :members:
    :special-members: __init__
